@@ -724,19 +724,14 @@ impl Iterator for HighlightIter<'_> {
     }
 }
 
-#[derive(Clone)]
+#[derive(Clone, Default)]
 pub(crate) enum IncludedChildren {
+    #[default]
     None,
     All,
     Unnamed,
 }
 
-impl Default for IncludedChildren {
-    fn default() -> Self {
-        Self::None
-    }
-}
-
 // Compute the ranges that should be included when parsing an injection.
 // This takes into account three things:
 // * `parent_ranges` - The ranges must all fall within the *current* layer's ranges.
